import { Module } from "@nestjs/common";
import { JwtModule } from "@nestjs/jwt";
import { TypeOrmModule } from "@nestjs/typeorm";
import JwtConfigService from "src/core/jwt/jwt-config.service";
import JwtHelper from "src/core/jwt/jwt.helper";
import { ChangePasswordTokenRepository } from "../change-password-token/change-password-token.repository";
import { EmailNotifierRepository } from "../email-notifier/email-notifier-repository";
import { MailSenderService } from "../mail-sender/mail-sender.service";
import { SendEmailRepository } from "../send-email/send-email-repository";
import { SendEmailService } from "../send-email/send-email.service";
import { UsersRepository } from "../users/user.repository";
import { AuthController } from "./auth.controller";
import { AuthService } from "./auth.service";
import { AlpineiqService } from "../alpineiq/alpineiq.service";
import { RetailerServiceRepository } from "../dutchie-plus/custom-services/retailer-service/retailer-service.repository";

@Module({
    imports: [
        TypeOrmModule.forFeature([UsersRepository]),
        TypeOrmModule.forFeature([SendEmailRepository]),
        TypeOrmModule.forFeature([
            EmailNotifierRepository,
            ChangePasswordTokenRepository,
            RetailerServiceRepository
        ]),
        JwtModule.registerAsync({
            useClass: JwtConfigService
        })
    ],
    controllers: [AuthController],
    providers: [AuthService, JwtHelper, SendEmailService, MailSenderService, AlpineiqService]
})
export class AuthModule {
}
