import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateFeaturedBrandDto } from "./dto/create-featured-brand.dto";
import { UpdateFeaturedBrandDto } from "./dto/update-featured-brand.dto";
import { FeaturedBrand } from "./entities/featured-brand.entity";

@EntityRepository(FeaturedBrand)
export class FeaturedBrandRepository extends Repository<FeaturedBrand> {
    async createEntity(dto: CreateFeaturedBrandDto): Promise<FeaturedBrand | Error> {
        try {
            const {
                link,
                image
            } = dto;
            const entity = this.create({
                link,
                image
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<FeaturedBrand | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateFeaturedBrandDto): Promise<FeaturedBrand | Error> {
        try {
            await this.update(id, {
                link: dto.link,
                image: dto.image
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<FeaturedBrand[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
              .createQueryBuilder()
              .update(FeaturedBrand)
              .set({ isDeleted: true })
              .where("id = :id", { id: id })
              .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}