import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateSocialPackDto } from "./dto/create-social-pack.dto";
import { UpdateSocialPackDto } from "./dto/update-social-pack.dto";
import { SocialPack } from "./entities/social-pack.entity";

@EntityRepository(SocialPack)
export class SocialPackRepository extends Repository<SocialPack> {
    async createEntity(dto: CreateSocialPackDto): Promise<SocialPack | Error> {
        try {
            const {
                className,
                link
            } = dto;
            const entity = this.create({
                className,
                link
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<SocialPack | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateSocialPackDto): Promise<SocialPack | Error> {
        try {
            await this.update(id, {
                className: dto.className,
                link: dto.link
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<SocialPack[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
              .createQueryBuilder()
              .update(SocialPack)
              .set({ isDeleted: true })
              .where("id = :id", { id: id })
              .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}